@@ -2,8 +2,6 @@ import json
 import os
 from dataclasses import dataclass
 
-from deprecated.sphinx import versionchanged
-
 from datagen import modalities
 from datagen.components.datapoint.entity import base
 
@@ -20,7 +18,7 @@ class DataPoint(base.DataPoint):
 
     @modalities.textual_modality
     def keypoints(self) -> modalities.TextualModality:
-        return self._get_keypoints_v2() if self._should_use_keypoints_v2() else self._get_keypoints_v1()
+        return self._get_keypoints_v2() if self._use_keypoints_v2() else self._get_keypoints_v1()
 
     def _get_keypoints_v1(self) -> modalities.TextualModality:
         self._handle_keypoints_v1()
@@ -31,7 +29,7 @@ class DataPoint(base.DataPoint):
             factory_name="keypoints", file_name=os.path.join("key_points", "all_key_points.json")
         )
 
-    def _should_use_keypoints_v2(self) -> bool:
+    def _use_keypoints_v2(self) -> bool:
         v2_all_keypoints_file_path = self.camera_path.joinpath("key_points", "all_key_points.json")
         return v2_all_keypoints_file_path.exists()
 
